@@ -2,6 +2,7 @@ pub mod de;
 pub mod error;
 pub mod meta;
 pub mod ser;
+pub mod temporal;
 
 use std::borrow::Cow;
 
@@ -63,6 +64,7 @@ impl<'a> Serialize for DuperInner<'a> {
             }
             DuperInner::String(string) => serializer.serialize_str(string.as_ref()),
             DuperInner::Bytes(bytes) => serializer.serialize_bytes(bytes.as_ref()),
+            DuperInner::Temporal(temporal) => serializer.serialize_str(temporal.as_ref()),
             DuperInner::Integer(integer) => serializer.serialize_i64(*integer),
             DuperInner::Float(float) => serializer.serialize_f64(*float),
             DuperInner::Boolean(boolean) => serializer.serialize_bool(*boolean),
@@ -440,7 +442,7 @@ mod serde_tests {
 
     use crate::{
         DuperArray, DuperBytes, DuperIdentifier, DuperInner, DuperKey, DuperObject, DuperString,
-        DuperTuple, DuperValue, PrettyPrinter,
+        DuperTemporal, DuperTuple, DuperValue, PrettyPrinter,
         serde::{de::Deserializer, ser::Serializer},
     };
 
@@ -560,6 +562,20 @@ mod serde_tests {
                         inner: DuperInner::Bytes(DuperBytes::from(&br"/\"[..])),
                     },
                 ),
+                (
+                    DuperKey::from("temporal"),
+                    DuperValue {
+                        identifier: Some(
+                            DuperIdentifier::try_from("PlainTime").expect("valid identifier"),
+                        ),
+                        inner: DuperInner::Temporal(
+                            DuperTemporal::try_plain_time_from(std::borrow::Cow::Borrowed(
+                                "16:20:00",
+                            ))
+                            .expect("valid PlainTime"),
+                        ),
+                    },
+                ),
                 (
                     DuperKey::from("integer"),
                     DuperValue {
@@ -593,7 +609,63 @@ mod serde_tests {
         let serialized = serialize_duper(&value);
         assert_snapshot!(serialized);
         let deserialized = deserialize_duper(&serialized);
-        assert_eq!(value, deserialized);
+        assert_eq!(
+            deserialized,
+            DuperValue {
+                identifier: None,
+                inner: DuperInner::Object(DuperObject(vec![
+                    (
+                        DuperKey::from("string"),
+                        DuperValue {
+                            identifier: None,
+                            inner: DuperInner::String(DuperString::from("Hello world!")),
+                        },
+                    ),
+                    (
+                        DuperKey::from("bytes"),
+                        DuperValue {
+                            identifier: None,
+                            inner: DuperInner::Bytes(DuperBytes::from(&br"/\"[..])),
+                        },
+                    ),
+                    (
+                        DuperKey::from("temporal"),
+                        DuperValue {
+                            identifier: None,
+                            inner: DuperInner::String(DuperString::from("16:20:00",),),
+                        },
+                    ),
+                    (
+                        DuperKey::from("integer"),
+                        DuperValue {
+                            identifier: None,
+                            inner: DuperInner::Integer(1337),
+                        },
+                    ),
+                    (
+                        DuperKey::from("float"),
+                        DuperValue {
+                            identifier: None,
+                            inner: DuperInner::Float(8.25),
+                        },
+                    ),
+                    (
+                        DuperKey::from("boolean"),
+                        DuperValue {
+                            identifier: None,
+                            inner: DuperInner::Boolean(true),
+                        },
+                    ),
+                    (
+                        DuperKey::from("null"),
+                        DuperValue {
+                            identifier: None,
+                            inner: DuperInner::Null,
+                        },
+                    ),
+                ])),
+            }
+        );
 
         let value = DuperValue {
             identifier: Some(DuperIdentifier::try_from("MyScalars").expect("valid identifier")),
@@ -610,6 +682,17 @@ mod serde_tests {
                     ),
                     inner: DuperInner::Bytes(DuperBytes::from(&br"/\"[..])),
                 },
+                DuperValue {
+                    identifier: Some(
+                        DuperIdentifier::try_from("MyTemporal").expect("valid identifier"),
+                    ),
+                    inner: DuperInner::Temporal(
+                        DuperTemporal::try_unspecified_from(std::borrow::Cow::Borrowed(
+                            "2012-12-21",
+                        ))
+                        .expect("valid PlainTime"),
+                    ),
+                },
                 DuperValue {
                     identifier: Some(DuperIdentifier::try_from("MyInt").expect("valid identifier")),
                     inner: DuperInner::Integer(1337),
@@ -637,6 +720,43 @@ mod serde_tests {
         let serialized = serialize_duper(&value);
         assert_snapshot!(serialized);
         let deserialized = deserialize_duper(&serialized);
-        assert_eq!(value, deserialized);
+        assert_eq!(
+            deserialized,
+            DuperValue {
+                identifier: Some(DuperIdentifier::try_from("MyScalars").expect("valid identifier")),
+                inner: DuperInner::Array(DuperArray(vec![
+                    DuperValue {
+                        identifier: None,
+                        inner: DuperInner::String(DuperString::from("Hello world!")),
+                    },
+                    DuperValue {
+                        identifier: None,
+                        inner: DuperInner::Bytes(DuperBytes::from(&br"/\"[..])),
+                    },
+                    DuperValue {
+                        identifier: None,
+                        inner: DuperInner::String(DuperString::from("2012-12-21"))
+                    },
+                    DuperValue {
+                        identifier: Some(
+                            DuperIdentifier::try_from("MyInt").expect("valid identifier")
+                        ),
+                        inner: DuperInner::Integer(1337),
+                    },
+                    DuperValue {
+                        identifier: None,
+                        inner: DuperInner::Float(8.25),
+                    },
+                    DuperValue {
+                        identifier: None,
+                        inner: DuperInner::Boolean(true),
+                    },
+                    DuperValue {
+                        identifier: None,
+                        inner: DuperInner::Null,
+                    },
+                ])),
+            }
+        );
     }
 }
