@@ -2,11 +2,12 @@
 
 use crate::{
     ast::{
-        DuperArray, DuperBytes, DuperIdentifier, DuperObject, DuperString, DuperTuple, DuperValue,
+        DuperArray, DuperBytes, DuperIdentifier, DuperObject, DuperString, DuperTemporal,
+        DuperTuple, DuperValue,
     },
     format::{
         format_boolean, format_duper_bytes, format_duper_string, format_float, format_integer,
-        format_key, format_null,
+        format_key, format_null, format_temporal,
     },
     visitor::DuperVisitor,
 };
@@ -169,7 +170,10 @@ impl<'pp> DuperVisitor for PrettyPrinter<'pp> {
                 self.buf.push_str("(())");
             } else if tuple.len() == 1 {
                 self.buf.push_str("((");
-                tuple.get(0).unwrap().accept(self);
+                tuple
+                    .get(0)
+                    .expect("tuple contains one element")
+                    .accept(self);
                 self.buf.push_str("))");
             } else {
                 self.buf.push_str("((\n");
@@ -187,7 +191,10 @@ impl<'pp> DuperVisitor for PrettyPrinter<'pp> {
             self.buf.push_str("()");
         } else if tuple.len() == 1 {
             self.buf.push('(');
-            tuple.get(0).unwrap().accept(self);
+            tuple
+                .get(0)
+                .expect("tuple contains one element")
+                .accept(self);
             self.buf.push(')');
         } else {
             self.buf.push_str("(\n");
@@ -256,6 +263,21 @@ impl<'pp> DuperVisitor for PrettyPrinter<'pp> {
         }
     }
 
+    fn visit_temporal<'a>(
+        &mut self,
+        identifier: Option<&DuperIdentifier<'a>>,
+        temporal: &DuperTemporal<'a>,
+    ) -> Self::Value {
+        if !self.strip_identifiers
+            && let Some(identifier) = identifier
+        {
+            let value = format_temporal(temporal);
+            self.buf.push_str(&format!("{identifier}({value})"));
+        } else {
+            self.buf.push_str(&format_temporal(temporal));
+        }
+    }
+
     fn visit_integer(
         &mut self,
         identifier: Option<&DuperIdentifier<'_>>,
