@@ -2,11 +2,12 @@
 
 use crate::{
     ast::{
-        DuperArray, DuperBytes, DuperIdentifier, DuperObject, DuperString, DuperTuple, DuperValue,
+        DuperArray, DuperBytes, DuperIdentifier, DuperObject, DuperString, DuperTemporal,
+        DuperTuple, DuperValue,
     },
     format::{
         format_boolean, format_duper_bytes, format_duper_string, format_float, format_integer,
-        format_key, format_null,
+        format_key, format_null, format_temporal,
     },
     visitor::DuperVisitor,
 };
@@ -16,14 +17,16 @@ use crate::{
 pub struct Serializer {
     buf: String,
     strip_identifiers: bool,
+    minify: bool,
 }
 
 impl Serializer {
-    /// Create a new [`Serializer`] visitor with the provided option.
-    pub fn new(strip_identifiers: bool) -> Self {
+    /// Create a new [`Serializer`] visitor with the provided options.
+    pub fn new(strip_identifiers: bool, minify: bool) -> Self {
         Self {
             buf: String::new(),
             strip_identifiers,
+            minify,
         }
     }
 
@@ -52,10 +55,18 @@ impl DuperVisitor for Serializer {
             self.buf.push_str("({");
             for (i, (key, value)) in object.iter().enumerate() {
                 self.buf.push_str(&format_key(key));
-                self.buf.push_str(": ");
+                if self.minify {
+                    self.buf.push(':');
+                } else {
+                    self.buf.push_str(": ");
+                }
                 value.accept(self);
                 if i < len - 1 {
-                    self.buf.push_str(", ");
+                    if self.minify {
+                        self.buf.push(',');
+                    } else {
+                        self.buf.push_str(", ");
+                    }
                 }
             }
             self.buf.push_str("})");
@@ -63,10 +74,18 @@ impl DuperVisitor for Serializer {
             self.buf.push('{');
             for (i, (key, value)) in object.iter().enumerate() {
                 self.buf.push_str(&format_key(key));
-                self.buf.push_str(": ");
+                if self.minify {
+                    self.buf.push(':');
+                } else {
+                    self.buf.push_str(": ");
+                }
                 value.accept(self);
                 if i < len - 1 {
-                    self.buf.push_str(", ");
+                    if self.minify {
+                        self.buf.push(',');
+                    } else {
+                        self.buf.push_str(", ");
+                    }
                 }
             }
             self.buf.push('}');
@@ -88,7 +107,11 @@ impl DuperVisitor for Serializer {
             for (i, value) in array.iter().enumerate() {
                 value.accept(self);
                 if i < len - 1 {
-                    self.buf.push_str(", ");
+                    if self.minify {
+                        self.buf.push(',');
+                    } else {
+                        self.buf.push_str(", ");
+                    }
                 }
             }
             self.buf.push_str("])");
@@ -97,7 +120,11 @@ impl DuperVisitor for Serializer {
             for (i, value) in array.iter().enumerate() {
                 value.accept(self);
                 if i < len - 1 {
-                    self.buf.push_str(", ");
+                    if self.minify {
+                        self.buf.push(',');
+                    } else {
+                        self.buf.push_str(", ");
+                    }
                 }
             }
             self.buf.push(']');
@@ -119,7 +146,11 @@ impl DuperVisitor for Serializer {
             for (i, value) in tuple.iter().enumerate() {
                 value.accept(self);
                 if i < len - 1 {
-                    self.buf.push_str(", ");
+                    if self.minify {
+                        self.buf.push(',');
+                    } else {
+                        self.buf.push_str(", ");
+                    }
                 }
             }
             self.buf.push_str("))");
@@ -128,7 +159,11 @@ impl DuperVisitor for Serializer {
             for (i, value) in tuple.iter().enumerate() {
                 value.accept(self);
                 if i < len - 1 {
-                    self.buf.push_str(", ");
+                    if self.minify {
+                        self.buf.push(',');
+                    } else {
+                        self.buf.push_str(", ");
+                    }
                 }
             }
             self.buf.push(')');
@@ -165,6 +200,21 @@ impl DuperVisitor for Serializer {
         }
     }
 
+    fn visit_temporal<'a>(
+        &mut self,
+        identifier: Option<&DuperIdentifier<'a>>,
+        temporal: &DuperTemporal<'a>,
+    ) -> Self::Value {
+        if !self.strip_identifiers
+            && let Some(identifier) = identifier
+        {
+            let value = format_temporal(temporal);
+            self.buf.push_str(&format!("{identifier}({value})"));
+        } else {
+            self.buf.push_str(&format_temporal(temporal));
+        }
+    }
+
     fn visit_integer(
         &mut self,
         identifier: Option<&DuperIdentifier<'_>>,
